/*
 * Copyright (c) 2012 xqj.net. All rights reserved.
 */

package net.xqj.marklogic.examples;

import javax.xml.xquery.XQDataSource;
import javax.xml.xquery.XQConnection;
import javax.xml.xquery.XQPreparedExpression;
import javax.xml.xquery.XQResultSequence;
import javax.xml.xquery.XQException;

import javax.xml.namespace.QName;

import net.xqj.marklogic.MarkLogicXQDataSource;

/**
 * Basic Application showing how to bind Java variables to an XQuery.
**/

public class BindingVariables
{
	public static void main(String[] args) throws XQException
	{
		if(args.length != 4)
		{
			System.out.println("Specify XDBC Hostname and Port.");
			System.out.println();
			System.out.println("usage: java BindingVariables host port user password");
			return;
		}

		String hostName = args[0];
		String port = args[1];
		String user = args[2];
		String password = args[3];

		XQDataSource ds = new MarkLogicXQDataSource();
		ds.setProperty("serverName", hostName);
		ds.setProperty("port", port);

		XQConnection xqc = ds.getConnection(user, password);

		// Define Expression
		XQPreparedExpression xqpe = xqc.prepareExpression(
			"declare variable $str as xs:string external;\n"+
			"declare variable $doc as document-node(element(e)) external;\n"+
			"fn:concat('String: ', $str),\n"+
			"fn:concat('Document: ', xdmp:quote($doc))"
		);

		// ... Bind String ...
		xqpe.bindString(
			new QName("str"),
			"Hello World",
			null);

		// ... Bind Document ...
		xqpe.bindDocument(
			new QName("doc"),
			"<e>Hello World</e>",
			null, null
		);

		XQResultSequence rs = xqpe.executeQuery();

		while(rs.next())
		{
			System.out.println(rs.getItemAsString(null));
		}

		xqc.close();

	}


}